<?php

function dashboard_view_cf_project_invoice_receipts_details($type, $project_id, $from_date, $to_date) {
    
    $sql = dashboard_get_cf_sql_for_project_invoice_receipts_details($type, $project_id, $from_date, $to_date);

    return db_query($sql, "dashboard_view_cf_project_invoice_receipts_details");  
}

function dashboard_view_cf_subcontractor_credit_note_receipts_details($type, $project_id, $from_date, $to_date) {
    
    $sql = dashboard_get_cf_sql_for_subcontractor_credit_note_receipts_details($type, $project_id, $from_date, $to_date);

    return db_query($sql, "dashboard_view_cf_subcontractor_credit_note_receipts_details");  
}

function dashboard_view_cf_utility_bill_credit_note_receipts_details($type, $project_id, $from_date, $to_date) {
    
    $sql = dashboard_get_cf_sql_for_utility_bill_credit_note_receipts_details($type, $project_id, $from_date, $to_date);

    return db_query($sql, "dashboard_view_cf_utility_bill_credit_note_receipts_details");  
}

function dashboard_view_cf_project_credit_note_paymets_details($type, $project_id, $from_date, $to_date) {
    
    $sql = dashboard_get_cf_sql_for_project_credit_note_payments_summary($type, $project_id, $from_date, $to_date);

    return db_query($sql, "dashboard_view_cf_project_credit_note_paymets_details");  
}

function dashboard_view_cf_subcontractor_invoice_payments($type, $project_id, $from_date, $to_date) {
    
    $sql = dashboard_get_cf_sql_for_subcontractor_invoice_payments_details($type, $project_id, $from_date, $to_date);

    return db_query($sql, "dashboard_view_cf_subcontractor_invoice_payments");  
}

function dashboard_view_cf_utility_bill_payments_details($type, $project_id, $from_date, $to_date) {
    
    $sql = dashboard_get_cf_sql_for_utility_bills_payments_details($type, $project_id, $from_date, $to_date);

    return db_query($sql, "dashboard_view_cf_utility_bill_payments_details");  
}